<?php
declare(strict_types=1);

namespace App\Controller;

use App\Forms\UploadFileForm;
use App\Objects\UploadedFileData;
use App\Service\FileSystemService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

class UploadController extends AbstractController
{
    #[Route(
        path: '/upload/{dirs?}',
        name: 'app_upload',
        requirements: ['dirs' => '.+'],
        defaults: ['dirs' => ''],
        methods: Request::METHOD_POST,
    )]
    public function __invoke(
        FileSystemService $fileSystemService,
        Request $request,
        string $dirs,
    ): Response
    {
        $fileData = new UploadedFileData(dir: $dirs);
        $form = $this->createForm(UploadFileForm::class, $fileData)->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $fileSystemService->uploadFile($fileData);
        }

        return $this->redirectToRoute('app_home');
    }
}